#include "platform.h"
#define FILTER_NAME libextractor_printable_XX_filter
#define FILTER_INIT_NAME libextractor_printable_XX_filter_init
#define EXTRACT_NAME libextractor_printable_XX_extract
#include "printableextractor.h"
